==> haskell-ansi-terminal-types-0.11.5-194.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-terminal-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ansi-terminal-types
version:              0.11.5
visibility:           public
id:                   ansi-terminal-types-0.11.5-FR1G7OvSAIl5TEdw9JuRHH
key:                  ansi-terminal-types-0.11.5-FR1G7OvSAIl5TEdw9JuRHH
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/UnkindPartition/ansi-terminal
synopsis:             Types and functions used to represent SGR aspects
description:
    The \'\''ANSI\'\'' standards refer to the visual style of
    displaying characters as their \'\''graphic rendition\'\''. The
    \'\''ANSI\'\'' codes to establish the graphic rendition for
    subsequent text are referred to as SELECT GRAPHIC RENDITION
    (SGR). This package exposes modules that export types and
    functions used to represent SGR aspects.

category:             User Interfaces
abi:                  dcb17c20b4dfe6816fee3304654a4734
exposed:              True
exposed-modules:      System.Console.ANSI.Types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ansi-terminal-types-0.11.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ansi-terminal-types-0.11.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ansi-terminal-types-0.11.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-terminal-types
hs-libraries:         HSansi-terminal-types-0.11.5-FR1G7OvSAIl5TEdw9JuRHH
depends:              base-4.18.2.1 colour-2.3.6-H6QKK8UT9PiEnQ6wB0s1YD
haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal-types/html/ansi-terminal-types.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal-types/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ansi-terminal-types-0.11.5-196-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-terminal-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ansi-terminal-types
version:              0.11.5
visibility:           public
id:                   ansi-terminal-types-0.11.5-4COH3669Yoo7naJje0KDG2
key:                  ansi-terminal-types-0.11.5-4COH3669Yoo7naJje0KDG2
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/UnkindPartition/ansi-terminal
synopsis:             Types and functions used to represent SGR aspects
description:
    The \'\''ANSI\'\'' standards refer to the visual style of
    displaying characters as their \'\''graphic rendition\'\''. The
    \'\''ANSI\'\'' codes to establish the graphic rendition for
    subsequent text are referred to as SELECT GRAPHIC RENDITION
    (SGR). This package exposes modules that export types and
    functions used to represent SGR aspects.

category:             User Interfaces
abi:                  d41bd1fdf75d4a83e540b08fb5ac965c
exposed:              True
exposed-modules:      System.Console.ANSI.Types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ansi-terminal-types-0.11.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ansi-terminal-types-0.11.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ansi-terminal-types-0.11.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-terminal-types
hs-libraries:         HSansi-terminal-types-0.11.5-4COH3669Yoo7naJje0KDG2
depends:              base-4.18.2.1 colour-2.3.6-DLRFrLUBudd2Y8gC5KfK2z
haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal-types/html/ansi-terminal-types.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal-types/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
